@@ -43,6 +43,8 @@ NS_ATOM           = 'http://www.w3.org/2005/Atom'
 NS_ATTENTION      = 'urn:xmpp:attention:0'                            # XEP-0224
 NS_AUTH           = 'jabber:iq:auth'
 NS_AVATAR         = 'http://www.xmpp.org/extensions/xep-0084.html#ns-metadata'
+NS_AVATAR_METADATA = 'urn:xmpp:avatar:metadata'						  # XEP-0084
+NS_AVATAR_DATA	  = 'urn:xmpp:avatar:data'						  	  # XEP-0084
 NS_BIND           = 'urn:ietf:params:xml:ns:xmpp-bind'
 NS_BLOCKING       = 'urn:xmpp:blocking'                               # XEP-0191
 NS_BOB            = 'urn:xmpp:bob'                                    # XEP-0231
